cris: update comments for generic idle conversion

As of commit 8dc7c5ecd8 ("cris: Use generic idle loop"), cris no
longer provides cpu_idle().

- On cris-v10, etrax_gpio_wake_up_check() is called from default_idle()
  instead of cpu_idle(),

- On cris-v32, etrax_gpio_wake_up_check() is not called from
  default_idle(), so remove this (copy-and-paste?) part.

Signed-off-by: Geert Uytterhoeven <[email protected]>
Reviewed-by: Jesper Nilsson <[email protected]>
Signed-off-by: Andrew Morton <[email protected]>
Signed-off-by: Linus Torvalds <[email protected]>
This commit is contained in:
Geert Uytterhoeven 2014-06-06 14:38:32 -07:00 • committed by Linus Torvalds
commit 835eeeed73
2 changed files with 3 additions and 7 deletions

View file

@ -833,8 +833,8 @@ static int __init gpio_init(void)
printk(KERN_INFO "ETRAX 100LX GPIO driver v2.5, (c) 2001-2008 "
"Axis Communications AB\n");
/* We call etrax_gpio_wake_up_check() from timer interrupt and
* from cpu_idle() in kernel/process.c
* The check in cpu_idle() reduces latency from ~15 ms to ~6 ms
* from default_idle() in kernel/process.c
* The check in default_idle() reduces latency from ~15 ms to ~6 ms
* in some tests.
*/
res = request_irq(TIMER0_IRQ_NBR, gpio_poll_timer_interrupt,

View file

@ -958,11 +958,7 @@ gpio_init(void)
printk(KERN_INFO "ETRAX FS GPIO driver v2.5, (c) 2003-2007 "
"Axis Communications AB\n");
/* We call etrax_gpio_wake_up_check() from timer interrupt and
* from cpu_idle() in kernel/process.c
* The check in cpu_idle() reduces latency from ~15 ms to ~6 ms
* in some tests.
*/
/* We call etrax_gpio_wake_up_check() from timer interrupt */
if (request_irq(TIMER0_INTR_VECT, gpio_poll_timer_interrupt,
IRQF_SHARED, "gpio poll", &alarmlist))
printk(KERN_ERR "timer0 irq for gpio\n");